pub struct ClientBuilder { /* private fields */ }Expand description
Build a Client with the pattern everyone likes.
Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new ClientBuilder. Without changes this will build as a Client with a socket, on a port chosen by the OS, connected to VRCHAT_OSC_ADDR.
pub fn with_server_ip(self, ip: IpAddr) -> ClientBuilder
pub fn with_server_port(self, port: u16) -> ClientBuilder
Sourcepub fn with_client_port(self, port: u16) -> ClientBuilder
pub fn with_client_port(self, port: u16) -> ClientBuilder
Port is already chosen by the OS if this is not used.